@@ -15,8 +15,8 @@ class TestRegionEdgeCases(unittest.TestCase):
     dir, _ = path.split(__file__)
     self.load_data_path = path.join(dir, 'data', 'OK')
 
-    self.sensors = pd.read_csv(
-      path.join(self.load_data_path, 'sensors.csv'),
+    self.sites = pd.read_csv(
+      path.join(self.load_data_path, 'sites.csv'),
       index_col='site_id'
     )
 
@@ -36,8 +36,8 @@ class TestRegionEdgeCases(unittest.TestCase):
     self.results = pd.read_csv(
       path.join(self.load_data_path, 'results_diffusion.csv')
     )
-    self.results_ignore_sensors = pd.read_csv(
-      path.join(self.load_data_path, 'results_diffusion_ignore_sensors.csv')
+    self.results_ignore_sites = pd.read_csv(
+      path.join(self.load_data_path, 'results_diffusion_ignore_sites.csv')
     )
 
 
@@ -46,9 +46,10 @@ class TestRegionEdgeCases(unittest.TestCase):
     Test that a DiffusionEstimator object can be initialized with region data containing regions that are all touching
     and that the results are as expected
     """
-    estimator = DiffusionEstimator(self.sensors, self.regions, self.actuals,
+    estimator = DiffusionEstimator(self.sites, self.regions, self.actuals,
                                             verbose=0)
 
+    self.assertIsNotNone(estimator.regions['neighbours'])
     self.assertEqual(estimator.get_adjacent_regions(['SW']), ['CR', 'KT', 'SE', 'SM', 'TW', 'W', 'WC'])
     result = estimator.get_estimations('NO2_mean', None, '2019-10-15')
 
@@ -60,18 +61,18 @@ class TestRegionEdgeCases(unittest.TestCase):
     self.assertIsInstance(result, pd.DataFrame)
     self.assertTrue(result.equals(self.results))
 
-  def test_ignore_sensors(self):
+  def test_ignore_sites(self):
     """
     Test that a DiffusionEstimator object can be initialized with region data containing regions that are all touching
-    and that the results are as expected when ignoring sensors
+    and that the results are as expected when ignoring sites
     """
-    estimator = DiffusionEstimator(self.sensors, self.regions, self.actuals, verbose=0)
+    estimator = DiffusionEstimator(self.sites, self.regions, self.actuals, verbose=0)
     result = estimator.get_estimations('NO2_mean', None, '2019-10-15', ignore_site_ids=['Camden Kerbside [AQ]'])
 
     #print('Result: \n {}'.format(result))
-    #print('Target: \n {}'.format(self.results_ignore_sensors))
+    #print('Target: \n {}'.format(self.results_ignore_sites))
 
     self.assertIsNotNone(estimator)
     self.assertIsNotNone(result)
     self.assertIsInstance(result, pd.DataFrame)
-    self.assertTrue(result.equals(self.results_ignore_sensors))
+    self.assertTrue(result.equals(self.results_ignore_sites))
